@@ -107,8 +107,12 @@ search_view (struct view *v, const char *pattern, int dir)
     for (i = dir > 0 ? 0 : v->s->nitems - 1; i != v->selected + dir; i += dir)
       if (regexec (&reg, v->s->items[i]->description, 0, NULL, 0) == 0)
 	{
+	  if (dir > 0)
+	    error ("Search wrapped to top.");
+	  else
+	    error ("Search wrapped to bottom.");
+
 	  found = 1;
-	  error ("Search wrapped to top.");
 	  break;
 	}
 
